@@ -5,7 +5,6 @@
 #### References: Mardia Kanti V. and Jupp Peter E. (2000)
 #### Directional statistics, page 225-226
 ################################
-
 embed.aov <- function(x, ina) {
   ## x contains all the data
   ## ina is an indicator variable of each sample
@@ -18,8 +17,7 @@ embed.aov <- function(x, ina) {
   Rbi <- sqrt( Rfast::rowsums(S^2) ) ## the mean resultant length of each group
   S <- Rfast::colmeans(x)
   Rbar <- sqrt( sum(S^2) )  ## the mean resultant length based on all the data
-  Ft <-  (n - g) * (p - 1) * ( sum(ni * Rbi^2) - n * Rbar^2) / ( (g - 1) *
-    (p - 1) * ( n - sum(ni * Rbi^2) ) )
+  Ft <-  (n - g) * (p - 1) * ( sum(ni * Rbi^2) - n * Rbar^2) / ( (g - 1) * (p - 1) * ( n - sum(ni * Rbi^2) ) )
   pvalue <- pf(Ft, (g - 1) * (p - 1), (n - g) * (p - 1), lower.tail = FALSE)
   res <- c(Ft, pvalue)
   names(res) <- c('F', 'p-value')
