@@ -13,20 +13,20 @@ kent.datacontour <- function(x) {
   ## latitude and longitude
   dm <- dim(x)
   if ( dm[2] == 3 ) {
-    u <- euclid.inv(x)
+    u <- Directional::euclid.inv(x)
   } else if ( dm[2] == 2 ) {
     u <- x
-    x <- euclid(x) ## Euclidean coordinates used by Kent (1982)
+    x <- Directional::euclid(x) ## Euclidean coordinates used by Kent (1982)
   }
 
   n <- dm[1]  ## sample size
-  a <- kent.mle(x) ## MLE estimation of the Kent distribution
+  a <- Directional::kent.mle(x) ## MLE estimation of the Kent distribution
   G <- a$G ## G matrix, the mean direction and the major-minor axes
   k <- a$param[1] ## kappa, concentration parameter
   b <- a$param[2] ## beta, ovalness
   gam <- c(0, k, 0)
   lam <- c(0, -b, b)
-  ckb <- fb.saddle(gam, lam)[3] ## logarithm of the normalising constant
+  ckb <- Directional::fb.saddle(gam, lam)[3] ## logarithm of the normalising constant
   n <- 100
   x1 <- seq(min(u[, 1]) - 5, max(u[, 1]) + 5, length = n)  ## latitude
   x2 <- seq(min(u[, 2]) - 5, max(u[, 2]) + 5, length = n)  ## longitude
@@ -34,7 +34,7 @@ kent.datacontour <- function(x) {
 
   for (i in 1:n) {
     for (j in 1:n) {
-      y <- euclid( c(x1[i], x2[j]) )
+      y <- Directional::euclid( c(x1[i], x2[j]) )
       can <-  -ckb + k * y %*% G[, 1] + b * (y %*% G[, 2])^2 -
         b * (y %*% G[, 3])^2
       if ( abs(exp( can) ) < Inf )  mat[i, j] <- exp(can)
